@@ -250,7 +250,7 @@ namespace mars {
         bool selected;
         /* todo: get drawid2 should be used, so far we assume every node
            uses two ids */
-        unsigned long drawID;
+        unsigned long drawID, drawID2;
         for(size_t i=0; i<simNodes.size(); ++i) {
           drawID = control->nodes->getDrawID(simNodes[i].index);
           if(!drawID) continue;
@@ -263,7 +263,10 @@ namespace mars {
             }
           }
           control->graphics->setDrawObjectSelected(drawID, selected);
-          control->graphics->setDrawObjectSelected(drawID+1, selected);
+          drawID2 = control->nodes->getDrawID2(simNodes[i].index);
+          if(drawID2) {
+            control->graphics->setDrawObjectSelected(drawID2, selected);
+          }
         }
       }
 
@@ -486,7 +489,7 @@ namespace mars {
 
               if(gc->getCameraType() == 1) map["projection"] = "perspective";
               else map["projection"] = "orthogonal";
-
+              map["moveSpeed"] = gc->getMoveSpeed();
               if(mouse == ODE_CAM) map["mouse"] = "default";
               else if(mouse == MICHA_CAM) map["mouse"] = "invert";
               else if(mouse == OSG_CAM) map["mouse"] = "osg";
@@ -535,7 +538,7 @@ namespace mars {
         map["contact"]["cfdir1"]["y"] = 0.;
         map["contact"]["cfdir1"]["z"] = 0.;
       }
-      std::vector<std::string> move {"cmax_num_contacts", "cerp", "ccfm", "cfriction1", "cfriction2", "cmotion1", "cmotion2", "cfds1", "cfds2", "cbounce", "cbounce_vel", "capprox", "coll_bitmask", "cfdir1"};
+      std::vector<std::string> move {"cmax_num_contacts", "cerp", "ccfm", "cfriction1", "cfriction2", "cmotion1", "cmotion2", "cfds1", "cfds2", "cbounce", "cbounce_vel", "capprox", "coll_bitmask", "cfdir1", "rolling_friction", "rolling_friction2", "spinning_friction"};
       for(auto it: move) {
         if(map.hasKey(it)) {
           map["contact"][it] = map[it];
